@@ -133,7 +133,8 @@ gs_app_row_format_version_update (GsApp *app)
 		version_update = tmp;
 
 	/* have both */
-	if (version_current != NULL && version_update != NULL) {
+	if (version_current != NULL && version_update != NULL &&
+	    g_strcmp0 (version_current, version_update) != 0) {
 		return g_strdup_printf ("%s ▶ %s",
 					version_current,
 					version_update);
@@ -361,7 +362,7 @@ gs_app_row_refresh (GsAppRow *app_row)
 	if (g_strcmp0 (gs_app_get_branch (priv->app), "master") == 0) {
 		g_autofree gchar *name = NULL;
 		/* TRANSLATORS: not translated to match what flatpak does */
-		name = g_strdup_printf ("(Nightly) %s",
+		name = g_strdup_printf ("%s (Nightly)",
 					gs_app_get_name (priv->app));
 		gtk_label_set_label (GTK_LABEL (priv->name_label), name);
 	} else {
