@@ -144,6 +144,8 @@ gs_cmd_refine_flag_from_string (const gchar *flag, GError **error)
 		return GS_PLUGIN_REFINE_FLAGS_REQUIRE_ORIGIN_HOSTNAME;
 	if (g_strcmp0 (flag, "origin-ui") == 0)
 		return GS_PLUGIN_REFINE_FLAGS_REQUIRE_ORIGIN_UI;
+	if (g_strcmp0 (flag, "runtime") == 0)
+		return GS_PLUGIN_REFINE_FLAGS_REQUIRE_RUNTIME;
 	g_set_error (error,
 		     GS_PLUGIN_ERROR,
 		     GS_PLUGIN_ERROR_NOT_SUPPORTED,
