@@ -451,9 +451,9 @@ build_no_results_label (GsShellExtras *self)
 	}
 	g_ptr_array_add (array, NULL);
 
-	/* TRANSLATORS: hyperlink title */
 	url = g_strdup_printf ("<a href=\"%s\">%s</a>",
 	                       gs_app_get_url (app, AS_URL_KIND_MISSING),
+                               /* TRANSLATORS: hyperlink title */
                                _("this website"));
 
 	codec_titles = build_comma_separated_list ((gchar **) array->pdata);
@@ -1045,7 +1045,8 @@ row_activated_cb (GtkListBox *list_box,
 
 	if (gs_app_get_state (app) == AS_APP_STATE_UNAVAILABLE &&
 	    gs_app_get_url (app, AS_URL_KIND_MISSING) != NULL) {
-		gs_app_show_url (app, AS_URL_KIND_MISSING);
+		gs_shell_show_uri (self->shell,
+		                   gs_app_get_url (app, AS_URL_KIND_MISSING));
 	} else {
 		gs_shell_show_app (self->shell, app);
 	}
