@@ -652,6 +652,11 @@ static void
 show_update_details (GsApp *app, GsShellUpdates *self)
 {
 	GtkWidget *dialog;
+	g_autofree gchar *str = NULL;
+
+	/* debug */
+	str = gs_app_to_string (app);
+	g_debug ("%s", str);
 
 	dialog = gs_update_dialog_new (self->plugin_loader);
 	gs_update_dialog_show_update_details (GS_UPDATE_DIALOG (dialog), app);
@@ -1218,8 +1223,7 @@ gs_shell_updates_upgrade_help_cb (GsUpgradeBanner *upgrade_banner,
 
 	/* open the link */
 	uri = gs_app_get_url (app, AS_URL_KIND_HOMEPAGE);
-	if (!gtk_show_uri (NULL, uri, GDK_CURRENT_TIME, &error))
-		g_warning ("failed to open %s: %s", uri, error->message);
+	gs_shell_show_uri (self->shell, uri);
 }
 
 static void
@@ -1236,6 +1240,26 @@ gs_shell_updates_invalidate_downloaded_upgrade (GsShellUpdates *self)
 		 gs_app_get_id (app));
 }
 
+static gboolean
+gs_shell_update_are_updates_in_progress (GsShellUpdates *self)
+{
+	GsUpdateList *update_list = GS_UPDATE_LIST (self->list_box_updates);
+	g_autoptr(GsAppList) list = gs_update_list_get_apps (update_list);
+	for (guint i = 0; i < gs_app_list_length (list); i++) {
+		GsApp *app = gs_app_list_index (list, i);
+		switch (gs_app_get_state (app)) {
+		case AS_APP_STATE_INSTALLING:
+		case AS_APP_STATE_REMOVING:
+		case AS_APP_STATE_PURCHASING:
+			return TRUE;
+			break;
+		default:
+			break;
+		}
+	}
+	return FALSE;
+}
+
 static void
 gs_shell_updates_changed_cb (GsPluginLoader *plugin_loader,
 			     GsShellUpdates *self)
@@ -1244,6 +1268,12 @@ gs_shell_updates_changed_cb (GsPluginLoader *plugin_loader,
 	 * then make sure all new packages are downloaded */
 	gs_shell_updates_invalidate_downloaded_upgrade (self);
 
+	/* check to see if any apps in the app list are in a processing state */
+	if (gs_shell_update_are_updates_in_progress (self)) {
+		g_debug ("ignoring updates-changed as updates in progress");
+		return;
+	}
+
 	/* refresh updates list */
 	gs_shell_updates_reload (GS_PAGE (self));
 }
